Data Providers & Readers
------------------------

Data Providers
==============
.. automodule:: gordo_components.data_provider.providers
    :members:
    :undoc-members:
    :show-inheritance:

IROC Reader
===========
.. automodule:: gordo_components.data_provider.iroc_reader
    :members:
    :undoc-members:
    :show-inheritance:

NCS Reader
==========
.. automodule:: gordo_components.data_provider.ncs_reader
    :members:
    :undoc-members:
    :show-inheritance:

Azure Utils
===========
.. automodule:: gordo_components.data_provider.azure_utils
    :members:
    :undoc-members:
    :show-inheritance:

Base Data Provider
==================
.. automodule:: gordo_components.data_provider.base
    :members:
    :undoc-members:
    :show-inheritance:
